LogicalScreenDesc

Struct LogicalScreenDesc 

pub struct LogicalScreenDesc { /* private fields */ }
The logical screen descriptor contains properties which apply to all frames in the file.

use gift::block::{
    ColorTableConfig, ColorTableExistence, ColorTableOrdering,
    LogicalScreenDesc
};

let desc = LogicalScreenDesc::default()
    .with_screen_width(64)
    .with_screen_height(64)
    .with_color_table_config(ColorTableConfig::new(
        ColorTableExistence::Present,
        ColorTableOrdering::NotSorted,
        16,
    ))
    .with_background_color_idx(1);

Implementations

Source

impl LogicalScreenDesc

pub fn with_screen_width(self, screen_width: u16) -> Self

Set the screen width

pub fn screen_width(self) -> u16

Get the screen width

pub fn with_screen_height(self, screen_height: u16) -> Self

Set the screen height

pub fn screen_height(self) -> u16

Get the screen height

pub fn equal_size(self, rhs: Self) -> bool

Check if screen sizes are equal

pub fn with_flags(self, flags: u8) -> Self

Set the flags which control the global color table configuration.

It is recommended to use with_color_table_config instead.

pub fn flags(self) -> u8

Get the flags which control the global color table configuration

pub fn color_resolution(self) -> u16

Get the color resolution (obsolete GIF feature)

pub fn color_table_config(self) -> ColorTableConfig

Get the global color table configuration

pub fn with_color_table_config(self, tbl: ColorTableConfig) -> Self

Set the global color table configuration

pub fn with_background_color_idx(self, background_color_idx: u8) -> Self

Set the background color index

pub fn background_color_idx(self) -> u8

Get the background color index

pub fn with_pixel_aspect_ratio(self, pixel_aspect_ratio: u8) -> Self

Set the pixel aspect ratio (obsolete GIF feature)

pub fn pixel_aspect_ratio(self) -> u8

Get the pixel aspect ratio (obsolete GIF feature)